==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/de_de/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Ausgehend von';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Eingehend';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Der Name des Parameters darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Der Parameter des Feldes darf nicht leer sein.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Der Name des Feldes darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Der Name des Feldes darf nicht leer sein.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Bitte wählen Sie eine gültige Methode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Bitte wählen Sie einen gültigen Typ aus.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Das angegebene Ereignis existiert nicht.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Der Rückruf darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Bitte geben Sie einen gültigen Rückruf ein.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Ein Webhook dieses Typs existiert bereits mit diesem Callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Die angegebene Firma existiert nicht.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/de_de/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Ausgehend von';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Eingehend';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Der Name des Parameters darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Der Parameter des Feldes darf nicht leer sein.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Der Name des Feldes darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Der Name des Feldes darf nicht leer sein.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Bitte wählen Sie eine gültige Methode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Bitte wählen Sie einen gültigen Typ aus.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Das angegebene Ereignis existiert nicht.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Der Rückruf darf nicht länger als 255 Zeichen sein.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Bitte geben Sie einen gültigen Rückruf ein.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Ein Webhook dieses Typs existiert bereits mit diesem Callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Die angegebene Firma existiert nicht.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'Das angegebene Ereignis existiert nicht.';
